@@ -1,11 +1,21 @@
 import socket
 class IoTGreenhouse(object):
     """IoT Greenhouse data object"""
-    def __init__(self, name=""): 
-        if not name:
-            self.name = socket.gethostname()
-        else:
+    def __init__(self, id=None, name=None): 
+        self.id = id
+        host_name = socket.gethostname()
+        if "Greenhouse" in host_name:
+            self.name = host_name
+            self.group = self.name[-4:-2]
+            self.number = self.name[-2:]
+        elif name:
             self.name = name
+            self.group = "xx"
+            self.number = "00"
+        else:
+            self.name = "testGH"
+            self.group = "xx"
+            self.number = "00"
         #house state
         self.led_red_state = None
         self.led_red_status = None
